@@ -1,11 +1,11 @@
-#' Predictions from a fitted metacart object
+#' Predictions from a fitted FE metacart object
 #'
 #' Returns a data frame of predicted effect sizes and moderators from a fitted metacart object
 #'
 #' @param object fitted model object of class "FEmrt".
-#' @param newdata data frame containing the values at which predictions are required.
+#' @param newdata data frame containing the values for which predictions are required.
 #' @param ... Arguments that pass to other methods.
-#' @return  A data frame containing the predicted effect size, the moderators, and the corresponding node lables in the fitted tree.
+#' @return  A data frame containing the predicted effect size, the moderators, and the corresponding node labels in the fitted tree.
 #' @importFrom stats as.formula delete.response model.frame model.response terms predict
 #' @export
 predict.FEmrt <- function(object, newdata, ...){
@@ -30,14 +30,14 @@ predict.FEmrt <- function(object, newdata, ...){
   
 }
 
-#' Predictions from a fitted metacart object
+#' Predictions from a fitted RE metacart object
 #'
 #' Returns a data frame of predicted effect sizes and moderators from a fitted metacart object
 #'
 #' @param object fitted model object of class "REmrt".
-#' @param newdata data frame containing the values at which predictions are required.
+#' @param newdata data frame containing the values for which predictions are required.
 #' @param ... Arguments that pass to other methods.
-#' @return  A data frame containing the predicted effect size, the moderators, and the corresponding node lables in the fitted tree.
+#' @return  A data frame containing the predicted effect size, the moderators, and the corresponding node labels in the fitted tree.
 #' @importFrom stats as.formula delete.response model.frame model.response terms predict
 #' @export
 predict.REmrt <- function(object, newdata, ...){
@@ -50,7 +50,7 @@ predict.REmrt <- function(object, newdata, ...){
     pred.g <- object$g[as.character(TNodes)]
     ci.lb <- object$ci.lb[as.character(TNodes)]
     ci.ub <- object$ci.ub[as.character(TNodes)]
-    res <- data.frame(g = pred.g, ci.lb = ci.lb, ci.ub = ci.ub, newdata)
+    res <- data.frame(g = pred.g, ci.lb = ci.lb, ci.ub = ci.ub, TNodes = TNodes, newdata)
     row.names(res) <- NULL
     res
     
